#!/usr/bin/env python3
'''Implementation of different exchange-correlation functionals.'''
from .utils import (ALIAS, get_exc, get_vxc, get_xc, get_zeta, IMPLEMENTED, parse_functionals,
                    parse_psp, XC_MAP)

__all__ = ['ALIAS', 'get_exc', 'get_vxc', 'get_xc', 'get_zeta', 'IMPLEMENTED', 'parse_functionals',
           'parse_psp', 'XC_MAP']



#!/usr/bin/env python3
'''eminus - A plane wave density functional theory code.

Minimal usage example to do a DFT calculation for helium::

   from eminus import Atoms, SCF
   atoms = Atoms('He', [0, 0, 0])
   SCF(atoms).run()
'''
from . import config
from .atoms import Atoms
from .dft import get_epsilon, get_psi
from .io import (read, read_cube, read_json, read_xyz, write, write_cube, write_json, write_pdb,
                 write_xyz)
from .logger import log
from .scf import RSCF, SCF, USCF
from .version import __version__, info

__all__ = ['config', 'Atoms', 'get_epsilon', 'get_psi', 'info', 'log', 'read', 'read_cube',
           'read_json', 'read_xyz', 'RSCF', 'SCF', 'USCF', 'write', 'write_cube', 'write_json',
           'write_pdb', 'write_xyz', '__version__']



#!/usr/bin/env python3
'''Package version number and version info function.'''
import importlib
import platform
import sys

__version__ = '2.4.0'
logo = (' ___ _____ _ ___ _ _ ___ \n'
        '| -_|     | |   | | |_ -|\n'
        '|___|_|_|_|_|_|_|___|___|\n')


def info():
    '''Print version numbers and availability of packages.'''
    dependencies = ('numpy', 'scipy')
    extras = ('torch', 'pyscf', 'plotly', 'nglview')
    dev = ('notebook', 'pylibxc', 'pytest', 'flake8', 'sphinx', 'furo')

    print(logo)
    print('--- Platform infos ---'
          f'\nPlatform  : {platform.system()} {platform.machine()}'
          f'\nRelease   : {platform.release()} {platform.version()}'
          '\n\n--- Version infos ---'
          f'\npython    : {sys.version.split()[0]}'
          f'\neminus    : {__version__}')
    for pkg in dependencies + extras + dev:
        try:
            module = importlib.import_module(pkg)
            try:
                print(f'{pkg.ljust(10)}: {module.__version__}')
            except AttributeError:
                # pylibxc does not use the standard version identifier
                print(f'{pkg.ljust(10)}: {module.version.__version__}')
        except ModuleNotFoundError:
            if pkg in dependencies:
                print(f'{pkg.ljust(10)}: Dependency not installed')
            elif pkg in extras:
                print(f'{pkg.ljust(10)}: Extra not installed')
    return


if __name__ == '__main__':
    info()



#!/usr/bin/env python3
'''Collection of constants and unit conversion functions.

For more about atomic units, see: https://en.wikipedia.org/wiki/Hartree_atomic_units
'''
# Ha in eV (https://en.wikipedia.org/wiki/Hartree)
electronvolt = eV = 27.211386245988
# Ha in kcal/mol (https://en.wikipedia.org/wiki/Hartree)
kcalmol = 627.5094740631
# a0 in Å (https://en.wikipedia.org/wiki/Bohr_radius)
Angstrom = A = 0.529177210903
# e * a0 in D (https://en.wikipedia.org/wiki/Hartree_atomic_units)
Debye = D = 2.541746473


def ha2ev(E):
    '''Convert Hartree to electronvolt.

    Args:
        E (float | ndarray): Energy in Hartree.

    Returns:
        float | ndarray: Energy in electronvolt.
    '''
    return E * electronvolt


def ev2ha(E):
    '''Convert electronvolt to Hartree.

    Args:
        E (float | ndarray): Energy in electronvolt.

    Returns:
        float | ndarray: Energy in Hartree.
    '''
    return E / electronvolt


def ha2kcalmol(E):
    '''Convert Hartree to kcal/mol.

    Args:
        E (float | ndarray): Energy in Hartree.

    Returns:
        float | ndarray: Energy in kcal/mol.
    '''
    return E * kcalmol


def kcalmol2ha(E):
    '''Convert kcal/mol to Hartree.

    Args:
        E (float | ndarray): Energy in kcal/mol.

    Returns:
        float | ndarray: Energy in Hartree.
    '''
    return E / kcalmol


def ev2kcalmol(E):
    '''Convert electronvolt to kcal/mol.

    Args:
        E (float | ndarray): Energy in electronvolt.

    Returns:
        float | ndarray: Energy in kcal/mol.
    '''
    return ha2kcalmol(ev2ha(E))


def kcalmol2ev(E):
    '''Convert kcal/mol to electronvolt.

    Args:
        E (float | ndarray): Energy in kcal/mol.

    Returns:
        float | ndarray: Energy in electronvolt.
    '''
    return ha2ev(kcalmol2ha(E))


def ha2ry(E):
    '''Convert Hartree to Rydberg.

    Args:
        E (float | ndarray): Energy in Hartree.

    Returns:
        float | ndarray: Energy in Rydberg.
    '''
    return 2 * E


def ry2ha(E):
    '''Convert Rydberg to Hartree.

    Args:
        E (float | ndarray): Energy in Rydberg.

    Returns:
        float | ndarray: Energy in Hartree.
    '''
    return E / 2


def ang2bohr(r):
    '''Convert Angstrom to Bohr.

    Args:
        r (float | ndarray): Length in Angstrom.

    Returns:
        float | ndarray: Length in Bohr.
    '''
    return r / Angstrom


def bohr2ang(r):
    '''Convert Bohr to Angstrom.

    Args:
        r (float | ndarray): Length in Bohr.

    Returns:
        float | ndarray: Length in Angstrom.
    '''
    return r * Angstrom


def ebohr2d(p):
    '''Convert e * Bohr to Debye.

    Args:
        p (float | ndarray): Electric dipole moment in e * Bohr.

    Returns:
        float | ndarray: Electric dipole moment in Debye.
    '''
    return p * Debye


def d2ebohr(p):
    '''Convert Debye to e * Bohr.

    Args:
        p (float | ndarray): Electric dipole moment in Debye.

    Returns:
        float | ndarray: Electric dipole moment in e * Bohr.
    '''
    return p / Debye
